<?php
/**
 * horizzon functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package horizzon
 */

if ( ! function_exists( 'horizzon_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function horizzon_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on horizzon, use a find and replace
		 * to change 'horizzon' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'horizzon', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'horizzon' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'horizzon_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'horizzon_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function horizzon_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'horizzon_content_width', 640 );
}
add_action( 'after_setup_theme', 'horizzon_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function horizzon_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'horizzon' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'horizzon' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'horizzon_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function horizzon_scripts() {
	wp_enqueue_style( 'horizzon-style', get_stylesheet_uri() );

    wp_enqueue_style( 'horizzon-hover-style', get_stylesheet_directory_uri().'/assets/css/hover.css', false, NULL, 'all');

	wp_enqueue_style('bootstrap', get_stylesheet_directory_uri().'/assets/bootstrap/css/bootstrap.min.css', false, NULL, 'all');

    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/font-awesome/css/font-awesome.min.css', array(), '4.7.0' );

	wp_enqueue_script( 'horizzon-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'horizzon-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

    wp_enqueue_style( 'horizzon-google-fonts', '//fonts.googleapis.com/css?family=Open+Sans:400,400italic,700,700italic', array() );

    wp_enqueue_script( 'horizzon-custom-js', get_template_directory_uri() . '/js/custom.js',array('jquery'), '' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'horizzon_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Customizer category.
 */
require get_template_directory() . '/inc/dropdown-category.php';


/**
 * Customizer Primary color.
 */
require get_template_directory() . '/inc/functions.php';

require get_template_directory() . '/qodethemes/hooks/header.php';


/**
 * Customizer
 */
require get_template_directory() . '/inc/customizer-register.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

function horizzon_circle_sanitize_allowed_html ( $input ) {
    $allowed_html = wp_kses_allowed_html();
    $output = wp_kses($input, $allowed_html );
    return $output;
}


/**for allow iframe**/
function horizzon_circle_sanitize_textarea( $input ) {
    if ( current_user_can( 'unfiltered_html' ) ) {
        $output = $input;
    } else {
        $output = horizzon_circle_sanitize_allowed_html( $input );
    }
    return $output;
}

   function horizzon_color_escaping_option_sanitize( $input ) {
        $input = esc_attr( $input );

        return $input;
    }